@@ -1,7 +1,6 @@
-from typing import Callable
-from typing import Optional
+from typing import Callable, Optional
 
-from myrabbit.core.consumer.reply import Reply
 from myrabbit.core.consumer.pika_message import PikaMessage
+from myrabbit.core.consumer.reply import Reply
 
 MessageHandler = Callable[[PikaMessage], Optional[Reply]]
